<!- template: sample_search_flat.html -->
<head>
  <title>search of {{ sample_name }} - chill-filter</title>
  {% include "_header.html" %}
{% include "_header.html" %}
</head>
<body>
<main class="container">

<h2>Sample search summary for: {{ sample_name }}</h2>
<p>
Based on the abundance profile, this looks like an assembly.
<p>
  Based on the results below, we estimate that at least
  <b>{{ "{:.1f}".format(f_found * 100) }}%</b>
  of your contigs will align to a known reference genome.
<p>
Your sample is about {{ "{:.1f}".format((1 - f_found) * 100) }}% unknown. This is likely to be novel sequence!

<h2>Sample breakdown</h2>

<table border=1>
  <tr> <th> <b>Percent assigned</b> </th> <th> <b>Reference genome or collection</b> </th> </tr>
  {% for item in gather_df.to_dict(orient='records') %}
   <tr>
     <td>{{ item['f_unique_weighted']|percent }} ({{ item|unique_flat_bp }})</td>
     <td> {{ item['match_description'] }}  </td>
   </tr>
  {% endfor %}
</table>

<p>

<a href='./' style="color:white"><button>Go to sample information page</a></button>
<a href="./download_csv" style="color:white"><button>Download spreadsheet of reports</button></a>
<a href="/" style="color:white"><button>Submit a new sample</button></a>

{% include "_footer.html" %}
</main>
</body>

</html>
