<!- template: sample_index.html -->
<head>
  <title>Sample: {{ sample_name }} - chill-filter</title>
  {% include "_header.html" %}
</head>
<body>
    <main class="container">

<h1>Sample summary: {{ sample_name }} </h1>

Name: {{ sig.name|default("(no name)", true) }}<p>

Estimated size of sample: {{ sum_weighted_hashes * sig.minhash.scaled / 1e6 }} Mbp<p>

Filename: <tt>{{ sig_filename }}</tt>    
    

<p>
  
<a href='./search' style="color:white"><button>Screen sample against genomes</a></button>
<a href="./download" style="color:white"><button>Download sourmash sketch</button></a>
<a href="./delete" style="color:white"><button>Delete sample</button></a>
<a href="/" style="color:white"><button>Submit a new sample</button></a>

{% include "_footer.html" %}
</main>
</body>
