

    <div class="parent-element" style="text-align: left">
    <hr style="border-width: 3px; border-color: black">

        <p>
          
        Links: <a href="/">Front page</a>
        | <A href="https://github.com/dib-lab/chill-filter/issues">Support forum</a>
        | <A href="/faq">Frequently Asked Questions</a>
        | <a href="/guide">User Guide</a>
<p>
  chill-filter is powered by <a href="https://sourmash.rtfd.io">sourmash</a>. <p>
Contact the team at <a href="mailto:chill@sourmash.bio">chill@sourmash.bio</a>!

    </div>
    
